@@ -1,6 +1,6 @@
 /*
   Copyright (c) 2009 Tobias Koenig <tokoe@kde.org>
-  Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
+  Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -112,7 +112,7 @@ void KAddressBookContactSelectionWidget::setAddGroupContact(bool addGroupContact
 void KAddressBookContactSelectionWidget::initGui()
 {
     QVBoxLayout *layout = new QVBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
 
     mMessageLabel = new QLabel;
     layout->addWidget(mMessageLabel);
@@ -173,7 +173,7 @@ void KAddressBookContactSelectionWidget::initGui()
     boxLayout->addWidget(mAddressBookContactsButton, 2, 0, Qt::AlignTop);
 
     QVBoxLayout *addressBookLayout = new QVBoxLayout;
-    addressBookLayout->setMargin(0);
+    addressBookLayout->setContentsMargins(0, 0, 0, 0);
     addressBookLayout->addWidget(mAddressBookSelection);
     addressBookLayout->addWidget(mAddressBookSelectionRecursive);
 
@@ -190,7 +190,7 @@ Akonadi::Item::List KAddressBookContactSelectionWidget::collectAllItems() const
                                              QStringList() << KContacts::Addressee::mimeType());
     job->fetchScope().fetchFullPayload();
     QProgressDialog progressDialog(nullptr);
-    progressDialog.setWindowTitle(i18n("Collect Contacts"));
+    progressDialog.setWindowTitle(i18nc("@title:window", "Collect Contacts"));
     progressDialog.setAutoClose(true);
     progressDialog.setMinimumDuration(1000);
     progressDialog.setLabelText(i18n("Fetch Contacts"));
